import os
import pytest
import pandas as pd
from stadtradeln_data_tools.pandas_importer import load_csv, write_csv


@pytest.fixture
def csv_filename():
    filename = "test.csv"
    df = pd.DataFrame({'edge_geo': ['LINESTRING(0 0,0 1)',
                                    'LINESTRING(0 1,1 1)',
                                    'LINESTRING(1 1,1 0)',
                                    'LINESTRING(1 0,0 0)'],
                       'occurrences': [3, 4, 5, 6]})
    df.to_csv(filename, index=False)
    yield filename
    os.remove(filename)


def test_load_csv(csv_filename):
    df = load_csv(csv_filename)
    assert (df.latitude_start == [0.0, 0.0, 1.0, 1.0]).all()
    assert (df.longitude_start == [0.0, 1.0, 1.0, 0.0]).all()
    assert (df.latitude_end == [0.0, 1.0, 1.0, 0.0]).all()
    assert (df.longitude_end == [1.0, 1.0, 0.0, 0.0]).all()
    assert (df.occurrences == [3, 4, 5, 6]).all()


@pytest.fixture
def dataframe():
    return pd.DataFrame({
        'latitude_start': [0., 1., 1., 2., 2., 3., 3., 0.],
        'longitude_start': [0., 0., 1., 1., 2., 2., 3., 3.],
        'latitude_end': [1., 1., 2., 2., 3., 3., 0., 0.],
        'longitude_end': [0., 1., 1., 2., 2., 3., 3., 0.],
        'occurrences': [1, 2, 3, 4, 5, 6, 7, 8],
        'additional_data': ['a', 'b', "c", "d", "e", "f", "g", "h"]
    })


def test_write_and_load_csv(dataframe):
    filename = "test.csv"
    write_csv(dataframe, filename)
    loaded_dataframe = load_csv(filename)
    os.remove(filename)
    assert dataframe.equals(loaded_dataframe)



import numpy as np
import pathlib
from stadtradeln_data_tools.constants import default_cache_dir, data_urls
from stadtradeln_data_tools.status import Status
from stadtradeln_data_tools.dataset_downloader import DownloadResult, download_dataset
from stadtradeln_data_tools.dataset_extractor import ExtractResult, extract_dataset
from stadtradeln_data_tools.dataset_clipper import ClipResult, clip_dataset
from stadtradeln_data_tools.pandas_importer import load_csv, write_csv


def download(
        year: int,
        dataset_type: str,
        download_dir: pathlib.Path = default_cache_dir,
) -> DownloadResult:
    """Downloads a whole (zipped) STADTRADELN dataset from the database of the BmVI and stores it locally.
    :param year: The year of when the dataset was collected
    :param dataset_type: The type of the dataset (e.g. "verkehrsmengen" or "geschwindigkeiten")
    :param download_dir: The directory the dataset should be stored in.
    :returns: An object containing meta-info about the download's result.
    """
    if year not in data_urls.keys():
        return DownloadResult(Status.UNKNOWN_DATASET, "")

    dataset_url = data_urls[year][dataset_type]
    dataset_filename = pathlib.Path(dataset_url).name
    print(f"Downloading {year} dataset to \"{download_dir / dataset_filename}\"")
    retry = True
    verify_ca_certificate = True
    overwrite = False
    while retry:
        download_result = download_dataset(
            dataset_url,
            destination_path=download_dir,
            verify_ca_certificate=verify_ca_certificate,
            overwrite=overwrite
        )
        if download_result.status == Status.UNKNOWN_DATASET:
            print("The dataset you requested does not exist, aborting.")
            return download_result
        elif download_result.status == Status.FILE_ALREADY_EXISTS:
            choice = input("Dataset already exists on your local disc. Download anyway? (Y/n) ")
            overwrite = True
            if choice != "Y" and choice != "y":
                print("Continuing without download.")
                return download_result
        elif download_result.status == Status.FAILURE:
            print(f"Download failed, data in \"{download_result.filepath}\" seems corrupted.")
            return download_result
        elif download_result.status == Status.SSL_ERROR:
            print("WARNING: Your CA-certificates could not be verified by the downloader. "
                  "If you do not trust your network, it is advised that you download the "
                  "files from the original BmVI website: "
                  "https://www.mcloud.de/web/guest/suche/-/results/detail/ECF9DF02-37DC-4268-B017-A7C2CF302006 "
                  f"and manually move them to \"{download_dir}\"")
            choice = input("Retry without certificate verification? (Y/n) ")
            verify_ca_certificate = False
            if choice != "Y" and choice != "y":
                print("Aborting.")
                return download_result
        elif download_result.status == Status.SUCCESS:
            retry = False
        else:
            print("Something unexpectedly went really wrong, sorry. "
                  "Pleas submit an issue with a short description of the steps "
                  "you made before encountering this error:")
            print("https://github.com/Duam/stadtradeln-data/issues/new")
            print("Aborting.")
            return download_result
    print(f"Compressed dataset is located in \"{download_result.filepath}\".")
    return download_result


def extract(
        tar_path: pathlib.Path,
        output_dir: pathlib.Path = None,
) -> ExtractResult:
    """Extracts a .csv.tar.gz dataset.
    :param tar_path: The path of the compressed dataset (.csv.tar.gz)
    :param output_dir: The directory that the file should be extracted to.
    :returns: An object containing meta-info about the extraction result.
    """
    print(f"Extracting dataset in \"{tar_path}\".")
    extract_result = extract_dataset(tar_path, output_dir)
    if extract_result.status == Status.UNKNOWN_DATASET:
        print(f"The compressed dataset was not found in \"{extract_result.filepath}\".")
        return extract_result
    elif extract_result.status == Status.FAILURE:
        print(f"Could not extract the dataset in \"{extract_result.filepath}\".")
        return extract_result
    elif extract_result.status == Status.FILE_ALREADY_EXISTS:
        print("Extracted file already exists, continuing.")
    print(f"Raw data is located in \"{extract_result.filepath}\".")
    return extract_result


def clip(
        filepath: pathlib.Path,
        output_filepath: pathlib.Path = None,
        latitude_min: float = -np.inf,
        latitude_max: float = np.inf,
        longitude_min: float = -np.inf,
        longitude_max: float = np.inf,
) -> ClipResult:
    """Clips a STADTRADELN dataset to a desired geographical region.
    :param filepath: The path to the STADTRADELN dataset in .csv format
    :param output_filepath: The path (directory + filename) of the clipped dataset.
    :param latitude_min: The minimum desired latitude.
    :param latitude_max: The maximum desired latitude.
    :param longitude_min: The minimum longitude.
    :param longitude_max: The maximum longitude.
    :returns: An object containing meta-info about the clipping result.
    """
    print(f"Clipping dataset \"{filepath}\".")
    print("Chosen geographical region:")
    print(f"\t{latitude_min} <= latitude <= {latitude_max}")
    print(f"\t{longitude_min} <= longitude <= {longitude_max}")
    output_filename = pathlib.Path(f"{filepath.with_suffix('').name}_clipped.csv")
    output_filepath = output_filepath if output_filepath is not None else filepath.parent / output_filename

    print("Loading & Clipping dataset. May take a while..")
    df = load_csv(filepath)
    df_clipped = clip_dataset(df, (latitude_min, latitude_max), (longitude_min, longitude_max))

    print(f"Writing clipped dataset to \"{output_filepath}\".")
    # Create output directory if it doesn't exist
    if not output_filepath.parent.is_dir():
        output_filepath.parent.mkdir(parents=True)

    write_csv(df_clipped, output_filepath)
    return ClipResult(Status.SUCCESS, "")



import tarfile
import pathlib
from stadtradeln_data_tools.status import Status
from dataclasses import dataclass


@dataclass
class ExtractResult:
    status: Status
    filepath: str


def extract_dataset(
        tar_path: pathlib.Path,
        output_dir: pathlib.Path = None,
) -> ExtractResult:
    """Extracts a .csv.tar.gz dataset.
    :tar_path: The path of the compressed dataset (.tar.gz).
    :output_dir: The directory that the files should be extracted to.
    :returns: An enum telling you if the extraction was successful or not.
    """
    filepath = tar_path.with_suffix('').with_suffix('')
    output_dir = output_dir if output_dir is not None else tar_path.parent
    output_filepath = output_dir / filepath.name

    if not tar_path.exists():
        return ExtractResult(Status.UNKNOWN_DATASET, tar_path)

    if not tarfile.is_tarfile(tar_path):
        return ExtractResult(Status.FAILURE, tar_path)

    if output_filepath.is_file():
        return ExtractResult(Status.FILE_ALREADY_EXISTS, output_filepath)

    with tarfile.open(tar_path) as file:
        file.extractall(output_dir)

    return ExtractResult(Status.SUCCESS, output_filepath)



import pytest
from typing import Tuple
from stadtradeln_data_tools.linestring_conversion import (
    get_linestring_from_coordinates,
    get_coordinates_from_linestring
)


@pytest.mark.parametrize(
    "start_coordinate, end_coordinate, expected_linestring",
    [
        ((1, 2), (3, 4), "LINESTRING(1 2,3 4)"),
        ((1.1, 2.2), (3.3, 4.4), "LINESTRING(1.1 2.2,3.3 4.4)")
    ]
)
def test_get_linestring_from_coordinates(
        start_coordinate: Tuple[float, float],
        end_coordinate: Tuple[float, float],
        expected_linestring: str,
):
    assert get_linestring_from_coordinates(start_coordinate, end_coordinate) == expected_linestring


@pytest.mark.parametrize(
    "linestring, expected_start_coordinate, expected_end_coordinate",
    [
        ("LINESTRING(1 2,3 4)", (1, 2), (3, 4)),
        ("LINESTRING(1.1 2.2,3.3 4.4)", (1.1, 2.2), (3.3, 4.4))
    ]
)
def test_get_linestring_from_coordinates(
        linestring: str,
        expected_start_coordinate: Tuple[float, float],
        expected_end_coordinate: Tuple[float, float],
):
    assert get_coordinates_from_linestring(linestring) ==\
           (expected_start_coordinate, expected_end_coordinate)





from typing import Tuple
from collections import namedtuple

Coordinate = namedtuple('Coordinate', ['latitude', 'longitude'])


def get_coordinates_from_linestring(
        linestring: str
) -> Tuple[Coordinate, Coordinate]:
    """Converts a GIS-readable linestring into two coordinate-pairs describing the line's endpoints.
    :param linestring: A string formatted like "LINESTRING(<latitude1> <longitude2>,<latitude2> <longitude2>)".
    :returns: Two coordinate-pairs having latitude and longitude, each.
    """
    endpoints = linestring.replace("LINESTRING(", "").replace(")", "").split(",")
    start_coordinate = Coordinate(*[float(coord) for coord in endpoints[0].split(" ")])
    end_coordinate = Coordinate(*[float(coord) for coord in endpoints[1].split(" ")])
    return start_coordinate, end_coordinate


def get_linestring_from_coordinates(
        start: Coordinate,
        end: Coordinate
) -> str:
    """Converts two coordinate-pairs into a GIS-readable linestring-format.
    :param start: Latitude and longitude of the line's start point.
    :param end: Latitude and longitude of the line's end point.
    :returns: A string formatted like "LINESTRING(<latitude1> <longitude2>,<latitude2> <longitude2>)".
    """
    start = Coordinate(float(start[0]), float(start[1]))
    end = Coordinate(float(end[0]), float(end[1]))
    return f'LINESTRING({start.latitude} {start.longitude},{end.latitude} {end.longitude})'



import pandas as pd
from typing import Tuple
from dataclasses import dataclass
from stadtradeln_data_tools.status import Status


@dataclass
class ClipResult:
    status: Status
    filepath: str


def clip_dataset(
        df: pd.DataFrame,
        latitude_lim: Tuple[float, float],
        longitude_lim: Tuple[float, float],
) -> pd.DataFrame:
    """Clips the given dataset to a desired rectangular geographic region.
    :param df: The dataset.
    :param latitude_lim: A tuple containing minimum and maximum allowed latitude values.
    :param longitude_lim: A tuple containing minimum and maximum allowed longitude values.
    :returns: The clipped dataset.
    """
    df = df[df.latitude_start.between(latitude_lim[0], latitude_lim[1])]
    df = df[df.latitude_end.between(latitude_lim[0], latitude_lim[1])]
    df = df[df.longitude_start.between(longitude_lim[0], longitude_lim[1])]
    df = df[df.longitude_end.between(longitude_lim[0], longitude_lim[1])]
    return df



import requests
import pathlib
from tqdm import tqdm
from dataclasses import dataclass
from stadtradeln_data_tools.status import Status
from stadtradeln_data_tools.constants import default_cache_dir


@dataclass
class DownloadResult:
    status: Status
    filepath: str


def download_dataset(
        url: str,
        destination_path: str = default_cache_dir,
        overwrite: bool = False,
        verify_ca_certificate: bool = False,
) -> DownloadResult:
    """Downloads a whole (zipped) STADTRADELN dataset from the database of the
    Bundesministerium für Verkehr und digitale Infrastructure (BmVI)
    and stores it locally.
    :param url: The URL pointing to the desired dataset.
    :param destination_path: The download destination directory.
    :param overwrite: If set, overwrites the local file.
    :param verify_ca_certificate: Verifies the CA-certificate if True.
        Download may fail if your CA-certificates are not set up properly.
        See https://stackoverflow.com/questions/63210851/python-requests-throwing-sslerror-after-downloading-certificate
    :returns: An enum telling you if the download was successful or not and (if successful) the resulting filepath.
    """
    destination_path = pathlib.Path(destination_path)
    filename = pathlib.Path(url).name
    filepath = pathlib.Path(destination_path, filename)

    if not destination_path.is_dir():
        destination_path.mkdir(parents=True)

    if filepath.is_file() and not overwrite:
        return DownloadResult(Status.FILE_ALREADY_EXISTS, filepath)

    # Get download metadata
    try:
        response = requests.get(url, verify=verify_ca_certificate, stream=True)
    except requests.exceptions.SSLError:
        return DownloadResult(Status.SSL_ERROR, "")

    # Create the progress bar
    total_size_in_bytes = int(response.headers.get('content-length', 0))
    block_size = 10 * 1024  # 10kB
    progress_bar = tqdm(total=total_size_in_bytes, unit='iB', ncols=100, unit_scale=True)

    # Download dataset
    with open(filepath, "w+b") as file:
        for data in response.iter_content(block_size):
            progress_bar.update(len(data))
            file.write(data)
    progress_bar.close()

    # Check download
    if total_size_in_bytes != 0 and progress_bar.n != total_size_in_bytes:
        return DownloadResult(Status.FAILURE, "")

    return DownloadResult(Status.SUCCESS, filepath)



import pathlib
import click
import numpy as np
from stadtradeln_data_tools.constants import default_cache_dir, data_urls
from stadtradeln_data_tools.status import Status
from stadtradeln_data_manager.cli_utils import (
    download as download_dataset,
    extract as extract_dataset,
    clip as clip_dataset
)


@click.group()
def cli():
    pass


@cli.command()
@click.argument("year", type=click.Choice([str(i) for i in data_urls.keys()]))
@click.argument("type", type=click.Choice(['verkehrsmengen', 'geschwindigkeiten'], case_sensitive=False))
@click.option("-d", "--destination-dir", type=click.Path(), default=default_cache_dir,
              help="The directory to store the downloaded STADTRADELN dataset in.")
@click.option("-x", "--extract", is_flag=True, default=False,
              help="Immediately extracts the compressed dataset after the download has finished.")
@click.pass_context
def download(ctx, year, dataset_type, destination_dir, extract):
    """Downloads a dataset.

    The dataset is determined by the year it was collected and by the kind of data you desire.

    By default, the dataset is stored on your local computer in the directory /tmp/stadtradeln_data/.
    """
    year = int(year)
    download_result = download_dataset(year, dataset_type, destination_dir)
    if download_result.status != Status.SUCCESS and download_result.status != Status.FILE_ALREADY_EXISTS:
        return

    if extract:
        extract_result = extract_dataset(year, download_result.filepath.parent, True)
        if not extract_result.status != Status.SUCCESS or not extract_result.status != Status.FILE_ALREADY_EXISTS:
            return

    click.echo("Done.")


@cli.command()
@click.argument("year", type=click.Choice([str(i) for i in data_urls.keys()]))
@click.argument("dataset_type", type=click.Choice(['verkehrsmengen', 'geschwindigkeiten'], case_sensitive=False))
@click.option("-d", "--data-dir", type=click.Path(), default=default_cache_dir,
              help="The directory containing the compressed dataset.")
@click.pass_context
def extract(ctx, year, dataset_type, data_dir):
    """Extracts a dataset to .csv format.
    that has been downloaded previously.
    The extracted dataset will be put in the same directory as the compressed file.
    """
    year = int(year)
    tar_filename = pathlib.Path(data_urls[year][dataset_type]).name
    tar_dir = pathlib.Path(data_dir)
    extract_result = extract_dataset(tar_dir / tar_filename, tar_dir)
    if not extract_result.status != Status.SUCCESS or not extract_result.status != Status.FILE_ALREADY_EXISTS:
        return


@cli.command()
@click.argument("year", type=click.Choice([str(i) for i in data_urls.keys()]))
@click.argument("dataset_type", type=click.Choice(['verkehrsmengen', 'geschwindigkeiten'], case_sensitive=False))
@click.option("-d", "--data-dir", type=click.Path(), default=default_cache_dir,
              help="The directory containing the whole dataset.")
@click.option("-latmin", "--latitude-min", type=float, default=-np.inf, help="Minimum latitude")
@click.option("-latmax", "--latitude-max", type=float, default=np.inf, help="Maximum latitude")
@click.option("-lonmin", "--longitude-min", type=float, default=-np.inf, help="Minimum longitude")
@click.option("-lonmax", "--longitude-max", type=float, default=np.inf, help="Maximum longitude")
@click.pass_context
def clip(ctx, year, dataset_type, data_dir, latitude_min, latitude_max, longitude_min, longitude_max):
    """Clips an extracted dataset to a desired geographical region.
    """
    year = int(year)
    filepath = pathlib.Path(data_urls[year][dataset_type]).with_suffix('').with_suffix('')
    filename = filepath.name
    output_filename = pathlib.Path(f"{filepath.with_suffix('').name}_clipped.csv")
    directory = pathlib.Path(data_dir)
    clip_result = clip_dataset(
        filepath=directory / filename,
        output_filepath=directory / output_filename,
        latitude_min=latitude_min,
        latitude_max=latitude_max,
        longitude_min=longitude_min,
        longitude_max=longitude_max)
    if not clip_result.status != Status.SUCCESS or not clip_result.status != Status.FILE_ALREADY_EXISTS:
        pass

    click.echo("Done.")


if __name__ == '__main__':
    cli()



import pytest
import pandas as pd
import copy
from stadtradeln_data_tools.dataset_clipper import clip_dataset
from typing import Tuple


def clip(
        df: pd.DataFrame,
        latitude_lim: Tuple[float, float],
        longitude_lim: Tuple[float, float],
) -> pd.DataFrame:
    """Clips the given STADTRADELN dataset to a desired rectangular geographic region.
    :param df: The STADTRADELN dataset.
    :param latitude_lim: A tuple containing minimum and maximum allowed latitude values.
    :param longitude_lim: A tuple containing minimum and maximum allowed longitude values.
    :returns: The clipped dataset.
    """
    df = df[df.latitude_start.between(latitude_lim[0], latitude_lim[1])]
    df = df[df.latitude_end.between(latitude_lim[0], latitude_lim[1])]
    df = df[df.longitude_start.between(longitude_lim[0], longitude_lim[1])]
    df = df[df.longitude_end.between(longitude_lim[0], longitude_lim[1])]
    return df


def create_dataset():
    return pd.DataFrame({
        'latitude_start': [0, 1, 1, 2, 2, 3, 3, 0],
        'longitude_start': [0, 0, 1, 1, 2, 2, 3, 3],
        'latitude_end': [1, 1, 2, 2, 3, 3, 0, 0],
        'longitude_end': [0, 1, 1, 2, 2, 3, 3, 0],
        'occurences': [1, 2, 3, 4, 5, 6, 7, 8]
    })


@pytest.mark.parametrize(
    "dataset, latitude_lim, longitude_lim",
    [
        (create_dataset(), (0, 3), (0, 3)),
        (create_dataset(), (0, 1), (0, 3)),
        (create_dataset(), (0, 0), (0, 1)),
        (create_dataset(), (0, -1), (1, 2)),
    ]
)
def test_get_linestring_from_coordinates(
        dataset: pd.DataFrame,
        latitude_lim: Tuple[float, float],
        longitude_lim: Tuple[float, float],
):
    dataset_copy = copy.deepcopy(dataset)  # Some pandas methods modify the original DataFrame
    clipped_dataset = clip_dataset(dataset, latitude_lim, longitude_lim)
    expected_clipped_dataset = clip(dataset_copy, latitude_lim, longitude_lim)
    assert expected_clipped_dataset.equals(clipped_dataset)



from stadtradeln_data_tools.pandas_importer import load_csv, write_csv
from stadtradeln_data_tools.dataset_downloader import DownloadResult, download_dataset
from stadtradeln_data_tools.dataset_extractor import ExtractResult, extract_dataset
from stadtradeln_data_tools.dataset_clipper import ClipResult, clip_dataset
from stadtradeln_data_tools.constants import data_urls, default_cache_dir
from stadtradeln_data_tools.linestring_conversion import (
    get_linestring_from_coordinates,
    get_coordinates_from_linestring
)



import pandas as pd
from stadtradeln_data_tools.linestring_conversion import (
    get_linestring_from_coordinates,
    get_coordinates_from_linestring
)


def load_csv(
        csv_path: str
) -> pd.DataFrame:
    """Loads a STADTRADELN dataset into a pandas.DataFrame and converts the
    single 'edge_geo' column from LINESTRING-format into four separate columns
    containing latitudes and longitudes of the line's endpoints.
    :param csv_path: The path to the STADTRADELN csv dataset.
    :returns: A pandas.DataFrame containing the data.
    """
    df = pd.read_csv(csv_path)
    lines = [get_coordinates_from_linestring(s) for s in df.edge_geo]
    start_points = [line_vertices[0] for line_vertices in lines]
    end_points = [line_vertices[1] for line_vertices in lines]
    remaining_data = df[set(df.columns).difference({'edge_geo', 'occurrences'})]
    return pd.DataFrame({
        'latitude_start': [coord.latitude for coord in start_points],
        'longitude_start': [coord.longitude for coord in start_points],
        'latitude_end': [coord.latitude for coord in end_points],
        'longitude_end': [coord.longitude for coord in end_points],
        'occurrences': df.occurrences,
        **dict(remaining_data)
    })


def write_csv(
        df: pd.DataFrame,
        csv_path: str
) -> None:
    """Writes a STADTRADELN dataset in pandas.DataFrame format to a .csv file.
    The given dataset must have columns "latitude_start", "latitude_end", "longitude_start", "longitude_end"
    and "occurrences".
    :param df: A pandas.DataFrame containing the data.
    :param csv_path: The path of the target .csv file.
    :returns: Nothing.
    """
    lines = [
        get_linestring_from_coordinates(
            (row.latitude_start, row.longitude_start),
            (row.latitude_end, row.longitude_end))
        for row in df.itertuples()
    ]
    remaining_data = df[set(df.columns).difference(
        {'latitude_start', 'longitude_start', 'latitude_end', 'longitude_end', 'occurrences'})]
    pd.DataFrame({
        'edge_geo': lines,
        'occurrences': df.occurrences,
        **dict(remaining_data)
    }).to_csv(csv_path, index=False)



import pathlib
import tempfile

data_urls = {
    2018: {
        'verkehrsmengen': 'https://www.mcloud.de/downloads/ingrid-group_ige-iplug-mcloud/'
                          'ECF9DF02-37DC-4268-B017-A7C2CF302006/verkehrsmengen_2018.csv.tar.gz',
        'geschwindigkeiten': 'https://www.mcloud.de/downloads/ingrid-group_ige-iplug-mcloud/'
                             '33427A5A-0ADB-40B1-8A1A-390B67B0380B/geschwindigkeiten_2018.csv.tar.gz'
    },
    2019: {
        'verkehrsmengen': 'https://www.mcloud.de/downloads/ingrid-group_ige-iplug-mcloud/'
                          'ECF9DF02-37DC-4268-B017-A7C2CF302006/verkehrsmengen_2019.csv.tar.gz',
        'geschwindigkeiten': 'https://www.mcloud.de/downloads/ingrid-group_ige-iplug-mcloud/'
                             '33427A5A-0ADB-40B1-8A1A-390B67B0380B/geschwindigkeiten_2019.csv.tar.gz'
    },
    2020: {
        'verkehrsmengen': 'https://www.mcloud.de/downloads/ingrid-group_ige-iplug-mcloud/'
                          'ECF9DF02-37DC-4268-B017-A7C2CF302006/verkehrsmengen_2020.csv.tar.gz',
        'geschwindigkeiten': 'https://www.mcloud.de/downloads/ingrid-group_ige-iplug-mcloud/'
                             '33427A5A-0ADB-40B1-8A1A-390B67B0380B/geschwindigkeiten_2020.csv.tar.gz'
    }
}

default_cache_dir = pathlib.Path(tempfile.gettempdir(), 'stadtradeln_data/')



import os
from setuptools import setup, find_packages


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name='stadtradeln-data',
    version="0.0.2-rc-6",
    setup_requires=['setuptools'],
    use_scm_version=False,
    install_requires=[
        'tqdm',
        'requests',
        'click',
        'pytest',
        'numpy',
        'pandas'
    ],
    python_requires='>=3.6',
    package_dir={'': 'src'},
    packages=find_packages('src'),
    license="MIT",
    url="https://github.com/Duam/stadtradeln-data",
    author="Paul Daum",
    author_email="paul.daum@posteo.de",
    description="A python package for downloading, extracting and clipping bicycle traffic count data "
                "from the STADTRADELN database",
    long_description=read('README.md'),
    long_description_content_type='text/markdown',
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "Topic :: Utilities",
        "License :: OSI Approved :: MIT License",
        "Intended Audience :: Science/Research",
        "Natural Language :: English",
        "Operating System :: Unix",
        "Topic :: Scientific/Engineering :: Information Analysis",
        "Typing :: Typed"
    ],
    entry_points={
        'console_scripts': [
            'stadtradeln-data-manager = stadtradeln_data_manager.__main__:cli'
        ]
    },
)
